package com.ruoyi.brewery.service;

import java.util.List;
import com.ruoyi.brewery.domain.WyBeerQrcodeBatch;

/**
 * 批次Service接口
 * 
 * @author ruoyi
 * @date 2024-12-21
 */
public interface IWyBeerQrcodeBatchService 
{
    /**
     * 查询批次
     * 
     * @param id 批次主键
     * @return 批次
     */
    public WyBeerQrcodeBatch selectWyBeerQrcodeBatchById(Long id);

    /**
     * 查询批次列表
     * 
     * @param wyBeerQrcodeBatch 批次
     * @return 批次集合
     */
    public List<WyBeerQrcodeBatch> selectWyBeerQrcodeBatchList(WyBeerQrcodeBatch wyBeerQrcodeBatch);

    List<WyBeerQrcodeBatch> selectWyBeerQrcodeBatchListWithData(WyBeerQrcodeBatch wyBeerQrcodeBatch);

    /**
     * 新增批次
     * 
     * @param wyBeerQrcodeBatch 批次
     * @return 结果
     */
    public int insertWyBeerQrcodeBatch(WyBeerQrcodeBatch wyBeerQrcodeBatch);

    /**
     * 修改批次
     * 
     * @param wyBeerQrcodeBatch 批次
     * @return 结果
     */
    public int updateWyBeerQrcodeBatch(WyBeerQrcodeBatch wyBeerQrcodeBatch);

    /**
     * 批量删除批次
     * 
     * @param ids 需要删除的批次主键集合
     * @return 结果
     */
    public int deleteWyBeerQrcodeBatchByIds(Long[] ids);

    /**
     * 删除批次信息
     * 
     * @param id 批次主键
     * @return 结果
     */
    public int deleteWyBeerQrcodeBatchById(Long id);
}
